<?xml version="1.0" ?><!DOCTYPE TS><TS language="es_419" version="2.1">
<context>
    <name>AboutDialog</name>
    <message>
        <source>Deepin Image Viewer</source>
        <translation>Visor de imágenes Deepin</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>Versión:</translation>
    </message>
</context>
<context>
    <name>AlbumBTContent</name>
    <message>
        <source>image</source>
        <translation>Imagen</translation>
    </message>
    <message>
        <source>images</source>
        <translation>Imágenes</translation>
    </message>
    <message>
        <source>album</source>
        <translation>Álbum</translation>
    </message>
    <message>
        <source>albums</source>
        <translation>Álbumes</translation>
    </message>
    <message>
        <source>Manage sync</source>
        <translation>Gestión de sincronización</translation>
    </message>
    <message>
        <source>Syncing: </source>
        <translation>Sincronizando:</translation>
    </message>
</context>
<context>
    <name>AlbumCreateDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Álbum nuevo</translation>
    </message>
    <message>
        <source>Unnamed</source>
        <translation>Sin nombre</translation>
    </message>
</context>
<context>
    <name>AlbumDelegate</name>
    <message>
        <source>Recent imported</source>
        <translation>Importados recientemente</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Mi favorito</translation>
    </message>
</context>
<context>
    <name>AlbumDeleteDialog</name>
    <message>
        <source>Are your sure to delete this album?</source>
        <translation>¿Esta seguro de borrar este álbum?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
</context>
<context>
    <name>AlbumPanel</name>
    <message>
        <source>Back</source>
        <translation>Atrás</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Mi favorito</translation>
    </message>
    <message>
        <source>Timeline</source>
        <translation>Línea de tiempo</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Añadir</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Puedes agregar directorio de sincronización o arrastrar y soltar imágenes a línea de tiempo </translation>
    </message>
</context>
<context>
    <name>AlbumsView</name>
    <message>
        <source>Unnamed</source>
        <translation>Sin nombre</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diapositivas</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renombrar</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <source>Deepin Image Viewer</source>
        <translation>Deepin Image Viewer</translation>
    </message>
</context>
<context>
    <name>CountingThread</name>
    <message>
        <source>Images</source>
        <translation>Imágenes</translation>
    </message>
</context>
<context>
    <name>DirImportDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Bien</translation>
    </message>
    <message>
        <source>Are you sure to add the pictures to the album?</source>
        <translation>¿Esta seguro de añadir las fotos al álbum?</translation>
    </message>
    <message>
        <source>Sync and Create</source>
        <translation>Sincronizar y crear</translation>
    </message>
    <message>
        <source>Sync</source>
        <translation>Sincronizar</translation>
    </message>
    <message>
        <source>Are you sure to add to the sync list and create the album named after this folder?</source>
        <translation>¿Está seguro de agregar a la lista de sincronización y crear el álbum con el nombre de esta carpeta?</translation>
    </message>
</context>
<context>
    <name>Exporter</name>
    <message>
        <source>JPEG(*.bmp *.gif *.jpg; *.jpeg; *.png *.pbm;*.pgm *.ppm *.xbm *.xpm *.svg *.dds *.icns*.jp2 *.mng *.tga *.tiff *.wbmp *.webp;)</source>
        <translation>JPEG(*.bmp *.gif *.jpg; *.jpeg; *.png *.pbm;*.pgm *.ppm *.xbm *.xpm *.svg *.dds *.icns*.jp2 *.mng *.tga *.tiff *.wbmp *.webp;)</translation>
    </message>
    <message>
        <source>Exported successfully</source>
        <translation>Exportado con éxito</translation>
    </message>
    <message>
        <source>Failed to export</source>
        <translation>Fallo al exportar</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
</context>
<context>
    <name>FileDeleteDialog</name>
    <message>
        <source>Are you sure to throw pictures to TRASH?</source>
        <translation>¿Esta seguro de tirar las fotos a la papelera?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
</context>
<context>
    <name>ImageInfoWidget</name>
    <message>
        <source>Image info</source>
        <translation>Información de imagen</translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <source>This file contains multiple pages, please use Evince to view all pages.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ImagesView</name>
    <message>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diapositivas</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimir</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Eliminar del álbum</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorito</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>No favorito</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Gire hacia la derecha</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Gire hacia la izquierda</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Establecer como fondo de pantalla</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Mostrar en administrador de archivos</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Información de imagen</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Añadir</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Usted puede Agregar directorio de sincronización o arrastrar y soltar imágenes a línea de tiempo </translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Añadir al álbum</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Añadir a nuevo álbum</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
</context>
<context>
    <name>Importer</name>
    <message>
        <source>Open Directory</source>
        <translation>Abrir directorio</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>No tiene permisos para ver esta imagen</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Fecha modificada</translation>
    </message>
    <message>
        <source>Dimension</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File size</source>
        <translation>Tamaño de archivo</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Espacio de color</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Modo de exposición</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Programa de exposición</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Tiempo de exposición</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Destello</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Apertura</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Longitud focal</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Máxima apertura</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Modo de medición</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Balance de blancos</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Compensación de destello</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Modelo de cámara</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Modelo de lente</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Fecha de la foto</translation>
    </message>
</context>
<context>
    <name>PrintOptionsPage</name>
    <message>
        <source>No scaling</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fit page to image</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fit image to page</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Scale to:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Millimeters</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Centimeters</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Inches</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Image Position</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Scaling</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Image Settings</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PrintPreviewDialog</name>
    <message>
        <source>Image Settings</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Blinds</source>
        <translation>Persianas</translation>
    </message>
    <message>
        <source>Switcher</source>
        <translation>Conmutador</translation>
    </message>
    <message>
        <source>Sliding</source>
        <translation>Corredizo</translation>
    </message>
    <message>
        <source>Ring</source>
        <translation>Anillo</translation>
    </message>
</context>
<context>
    <name>ScanPathsDialog</name>
    <message>
        <source>Select Directory</source>
        <translation>Seleccionar directorio</translation>
    </message>
    <message>
        <source>This directory is disabled to sync</source>
        <translation>Este directorio esta desactivado para sincronización</translation>
    </message>
    <message>
        <source>Add folder</source>
        <translation>Añadir carpeta</translation>
    </message>
    <message>
        <source>Sync Directory Management</source>
        <translation>Administración de directorios de sincronización</translation>
    </message>
    <message>
        <source>The directory list is empty</source>
        <translation>La lista de directorios esta vacía</translation>
    </message>
</context>
<context>
    <name>ScanPathsItem</name>
    <message>
        <source>Cancel sync</source>
        <translation>Cancelar sincronización</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Imágenes</translation>
    </message>
    <message>
        <source>The device has been removed</source>
        <translation>El dispositivo se ha eliminado</translation>
    </message>
    <message>
        <source>This directory no longer exists</source>
        <translation>Este directorio ya no existe</translation>
    </message>
    <message>
        <source>Calculating...</source>
        <translation>Calculando...</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Image Viewing</source>
        <translation>Visualización de imágenes</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Álbum</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ajustes</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diapositivas</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Finalizar Presentación</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Eliminar del álbum</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorito</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>No Favorito</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Gire hacia la derecha</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Gire hacia la izquierda</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Establecer como fondo de pantalla</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Mostrar en el administrador de archivos</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Información sobre la imagen</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Siguiente</translation>
    </message>
    <message>
        <source>Previous screen</source>
        <translation>Pantalla anterior</translation>
    </message>
    <message>
        <source>Next screen</source>
        <translation>Pantalla siguiente</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Nuevo album</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renombrar</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Salir</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Mostrar atajos</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>Please enter a new shortcut</source>
        <translation>Por favor ingrese un nuevo atajo</translation>
    </message>
</context>
<context>
    <name>ShortcutFrame</name>
    <message>
        <source>Shortcuts</source>
        <translation>Atajos</translation>
    </message>
    <message>
        <source>View Picture</source>
        <translation>Ver Imágen</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Álbum</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation>Restauración de Fábrica</translation>
    </message>
</context>
<context>
    <name>ShortcutKey</name>
    <message>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla Completa</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Mostrar Presentación</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Finalizar Presentación</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimir</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Remover del álbum</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorito</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>No Favorito</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Gire hacia la derecha</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Gire hacia la izquierda</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Configurar como Fondo de Pantalla</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Mostrar en Explorador de Archivos</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Info de Imágen</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Nuevo Álbum</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renombrar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
</context>
<context>
    <name>SlideShowPanel</name>
    <message>
        <source>End show</source>
        <translation>Finalizar Presentación</translation>
    </message>
    <message>
        <source>Pause/Play</source>
        <translation>Pausar/Reproducir</translation>
    </message>
</context>
<context>
    <name>SlideshowFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Configuración de la presentación</translation>
    </message>
    <message>
        <source>Switch effect</source>
        <translation>Cambiar Efecto</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Duración</translation>
    </message>
    <message>
        <source>Switch duration</source>
        <translation>Cambiar Duración</translation>
    </message>
    <message>
        <source>second</source>
        <translation>segundo</translation>
    </message>
</context>
<context>
    <name>TTLContent</name>
    <message>
        <source>Back</source>
        <translation>Atrás</translation>
    </message>
    <message>
        <source>Image management</source>
        <translation>Administrar imágen</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Mi favorito</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>1:1 Tamaño</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Ajustar a Ventana</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Gire hacia la izquierda</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Gire hacia la derecha</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>No Favorito</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorito</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>No se econtraron archivos de imágen</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TimelineBTContent</name>
    <message>
        <source>%1 image</source>
        <translation>%1 imágen</translation>
    </message>
    <message>
        <source>%1 images</source>
        <translation>%1 imágenes</translation>
    </message>
    <message>
        <source>Manage sync</source>
        <translation>Manager de Sincronización</translation>
    </message>
    <message>
        <source>Syncing: </source>
        <translation>Sincronizando:</translation>
    </message>
</context>
<context>
    <name>TimelinePanel</name>
    <message>
        <source>Album</source>
        <translation>Álbum</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Agregar</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Puede agregar directorio de sincronización o arrastrar y soltar imágenes a la línea de tiempo</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Agregar a Álbum</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Agregar a nuevo álbum</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla Completa</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Mostrar Presentación</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimir</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Copiar a Portapapeles</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorito</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>No Favorito</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Gire hacia la derecha</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Gire hacia la izquierda</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Establecer como fondo de pantalla</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Mostrar en Explorador de archivos</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Info de Imágen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
</context>
<context>
    <name>TitleFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Configuración de la presentación</translation>
    </message>
    <message>
        <source>Effect</source>
        <translation>Efecto</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Duración</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Marcadores</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Álbum</translation>
    </message>
</context>
<context>
    <name>TopAlbumTips</name>
    <message>
        <source>dd MMMM yyyy</source>
        <translation>dd MMMM aaaa</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Mi Favorito</translation>
    </message>
    <message>
        <source>Recent imported</source>
        <translation>Importados recientemente</translation>
    </message>
</context>
<context>
    <name>TopToolbar</name>
    <message>
        <source>New album</source>
        <translation>Nuevo álbum</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Configuraciones</translation>
    </message>
    <message>
        <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
        <translation>El visor de imágenes deepin es un gestor de imágenes rápido y moderno.</translation>
    </message>
    <message>
        <source>It is featured with image management, image viewing and basic image editing.</source>
        <translation>Viene con características básicas  de gestión, visualización y edición de imágenes.</translation>
    </message>
    <message>
        <source>Dark theme</source>
        <translation>Tema Oscuro </translation>
    </message>
    <message>
        <source>Deepin Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>El visor de imágenes deepin es un gestor de imágenes rápido y moderno.</translation>
    </message>
</context>
<context>
    <name>ViewPanel</name>
    <message>
        <source>Timeline</source>
        <translation>Línea de tiempo</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Agregar a álbum</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Agregar a nuevo álbum</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Salir de Pantalla Completa</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla Completa</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Mostrar Presentación</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimir</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Remover del álbum</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorito</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>No Favorito</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Mostrar navegación de ventana</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Ocultar navegación de ventana</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Gire hacia la derecha</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Gire hacia la izquierda</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Configurar como fondo de pantalla</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Mostrar en explorador de archivos</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Infor. de imágen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>All images</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>